==> tokodon-23.04.3.tar.xz: tokodon-23.04.3/src/autotests/profileeditortest.cpp <==
// SPDX-FileCopyrightText: 2022 Carl Schwan <carl@carlschwan.eu>
// SPDX-License-Identifier: LGPL-2.1-or-later

#include <QtTest/QtTest>

#include "accountmanager.h"
#include "helperreply.h"
#include "mockaccount.h"
#include "profileeditor.h"

class ProfileEditorTest : public QObject
{
    Q_OBJECT

private Q_SLOTS:
    void initTestCase()
    {
        account = new MockAccount();
        AccountManager::instance().addAccount(account);
        AccountManager::instance().selectAccount(account);
    }

    void cleanupTestCase()
    {
        AccountManager::instance().removeAccount(account);
    }

    void loadDataTest()
    {
        account->registerGet(account->apiUrl(QStringLiteral("/api/v1/accounts/verify_credentials")), new TestReply("verify_credentials.json", account));

        ProfileEditorBackend backend;
        account->setUsername("trwnh");
        backend.setAccount(account);
        QCOMPARE(backend.account(), account);
        QCOMPARE(backend.displayName(), "infinite love ⴳ");
        QCOMPARE(backend.note(),
                 "i have approximate knowledge of many things. perpetual student. (nb/ace/they)\r\n\r\nxmpp/email: a@trwnh.com\r\nhttps://trwnh.com\r\nhelp me "
                 "live: https://liberapay.com/at or https://paypal.me/trwnh\r\n\r\n- my triggers are moths and glitter\r\n- i have all notifs except mentions "
                 "turned off, so please interact if you wanna be friends! i literally will not notice otherwise\r\n- dm me if i did something wrong, so i can "
                 "improve\r\n- purest person on fedi, do not lewd in my presence\r\n- #1 ami cole fan account\r\n\r\n:fatyoshi:");
        QCOMPARE(backend.privacy(), "public");
        QCOMPARE(backend.sensitive(), false);
        QCOMPARE(backend.language(), "fr");
        QCOMPARE(backend.bot(), false);
        QCOMPARE(backend.avatarUrl(), QUrl("https://files.mastodon.social/accounts/avatars/000/014/715/original/34aa222f4ae2e0a9.png"));
        QCOMPARE(backend.backgroundUrl(), QUrl("https://files.mastodon.social/accounts/headers/000/014/715/original/5c6fc24edb3bb873.jpg"));
    }

    void setDataTest()
    {
        account->registerGet(account->apiUrl(QStringLiteral("/api/v1/accounts/verify_credentials")), new TestReply("verify_credentials.json", account));
        ProfileEditorBackend backend;
        account->setUsername("trwnh");
        backend.setAccount(account);
        backend.setDisplayName("Hello");
        backend.setAvatarUrl(QUrl(QLatin1String(DATA_DIR) + QLatin1String("/test.png")));
        backend.setBackgroundUrl(QUrl(QLatin1String(DATA_DIR) + QLatin1String("/test.png")));
        QCOMPARE("Hello", backend.displayName());
        QCOMPARE(QUrl(QLatin1String(DATA_DIR) + QLatin1String("/test.png")), backend.avatarUrl());
        QCOMPARE(QUrl(QLatin1String(DATA_DIR) + QLatin1String("/test.png")), backend.backgroundUrl());
        QCOMPARE(QString(), backend.backgroundUrlError());
        QCOMPARE(QString(), backend.avatarUrlError());
    }

private:
    MockAccount *account;
};

QTEST_MAIN(ProfileEditorTest)
#include "profileeditortest.moc"

==> tokodon_23.08.5.orig.tar.xz: tokodon-23.08.5/src/autotests/profileeditortest.cpp <==
// SPDX-FileCopyrightText: 2022 Carl Schwan <carl@carlschwan.eu>
// SPDX-License-Identifier: LGPL-2.1-or-later

#include <QtTest/QtTest>

#include "account/accountmanager.h"
#include "account/profileeditor.h"
#include "helperreply.h"
#include "mockaccount.h"

class ProfileEditorTest : public QObject
{
    Q_OBJECT

private Q_SLOTS:
    void initTestCase()
    {
        account = new MockAccount();
        AccountManager::instance().addAccount(account);
        AccountManager::instance().selectAccount(account);
    }

    void cleanupTestCase()
    {
        AccountManager::instance().removeAccount(account);
    }

    void loadDataTest()
    {
        account->registerGet(account->apiUrl(QStringLiteral("/api/v1/accounts/verify_credentials")), new TestReply("verify_credentials.json", account));

        ProfileEditorBackend backend;
        account->setUsername("trwnh");
        backend.setAccount(account);
        QCOMPARE(backend.account(), account);
        QCOMPARE(backend.displayName(), "infinite love ⴳ");
        QCOMPARE(backend.note(),
                 "i have approximate knowledge of many things. perpetual student. (nb/ace/they)\r\n\r\nxmpp/email: a@trwnh.com\r\nhttps://trwnh.com\r\nhelp me "
                 "live: https://liberapay.com/at or https://paypal.me/trwnh\r\n\r\n- my triggers are moths and glitter\r\n- i have all notifs except mentions "
                 "turned off, so please interact if you wanna be friends! i literally will not notice otherwise\r\n- dm me if i did something wrong, so i can "
                 "improve\r\n- purest person on fedi, do not lewd in my presence\r\n- #1 ami cole fan account\r\n\r\n:fatyoshi:");
        QCOMPARE(backend.privacy(), "public");
        QCOMPARE(backend.sensitive(), false);
        QCOMPARE(backend.language(), "fr");
        QCOMPARE(backend.bot(), false);
        QCOMPARE(backend.avatarUrl(), QUrl("https://files.mastodon.social/accounts/avatars/000/014/715/original/34aa222f4ae2e0a9.png"));
        QCOMPARE(backend.backgroundUrl(), QUrl("https://files.mastodon.social/accounts/headers/000/014/715/original/5c6fc24edb3bb873.jpg"));
    }

    void setDataTest()
    {
        account->registerGet(account->apiUrl(QStringLiteral("/api/v1/accounts/verify_credentials")), new TestReply("verify_credentials.json", account));
        ProfileEditorBackend backend;
        account->setUsername("trwnh");
        backend.setAccount(account);
        backend.setDisplayName("Hello");
        backend.setAvatarUrl(QUrl(QLatin1String(DATA_DIR) + QLatin1String("/test.png")));
        backend.setBackgroundUrl(QUrl(QLatin1String(DATA_DIR) + QLatin1String("/test.png")));
        QCOMPARE("Hello", backend.displayName());
        QCOMPARE(QUrl(QLatin1String(DATA_DIR) + QLatin1String("/test.png")), backend.avatarUrl());
        QCOMPARE(QUrl(QLatin1String(DATA_DIR) + QLatin1String("/test.png")), backend.backgroundUrl());
        QCOMPARE(QString(), backend.backgroundUrlError());
        QCOMPARE(QString(), backend.avatarUrlError());
    }

private:
    MockAccount *account;
};

QTEST_MAIN(ProfileEditorTest)
#include "profileeditortest.moc"
